/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM ../../../dist/idl/nsIURIFixup.idl
 */

#ifndef __gen_nsIURIFixup_h__
#define __gen_nsIURIFixup_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIURI; /* forward declaration */

class nsIInputStream; /* forward declaration */


/* starting interface:    nsIURIFixupInfo */
#define NS_IURIFIXUPINFO_IID_STR "c9b6cc32-c24e-4283-adaa-9290577fd609"

#define NS_IURIFIXUPINFO_IID \
  {0xc9b6cc32, 0xc24e, 0x4283, \
    { 0xad, 0xaa, 0x92, 0x90, 0x57, 0x7f, 0xd6, 0x09 }}

class NS_NO_VTABLE nsIURIFixupInfo : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IURIFIXUPINFO_IID)

  /* attribute nsISupports consumer; */
  NS_IMETHOD GetConsumer(nsISupports * *aConsumer) = 0;
  NS_IMETHOD SetConsumer(nsISupports *aConsumer) = 0;

  /* readonly attribute nsIURI preferredURI; */
  NS_IMETHOD GetPreferredURI(nsIURI * *aPreferredURI) = 0;

  /* readonly attribute nsIURI fixedURI; */
  NS_IMETHOD GetFixedURI(nsIURI * *aFixedURI) = 0;

  /* readonly attribute boolean fixupUsedKeyword; */
  NS_IMETHOD GetFixupUsedKeyword(bool *aFixupUsedKeyword) = 0;

  /* readonly attribute boolean inputHasProtocol; */
  NS_IMETHOD GetInputHasProtocol(bool *aInputHasProtocol) = 0;

  /* readonly attribute boolean inputHostHasDot; */
  NS_IMETHOD GetInputHostHasDot(bool *aInputHostHasDot) = 0;

  /* readonly attribute AUTF8String originalInput; */
  NS_IMETHOD GetOriginalInput(nsACString & aOriginalInput) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIURIFixupInfo, NS_IURIFIXUPINFO_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIURIFIXUPINFO \
  NS_IMETHOD GetConsumer(nsISupports * *aConsumer); \
  NS_IMETHOD SetConsumer(nsISupports *aConsumer); \
  NS_IMETHOD GetPreferredURI(nsIURI * *aPreferredURI); \
  NS_IMETHOD GetFixedURI(nsIURI * *aFixedURI); \
  NS_IMETHOD GetFixupUsedKeyword(bool *aFixupUsedKeyword); \
  NS_IMETHOD GetInputHasProtocol(bool *aInputHasProtocol); \
  NS_IMETHOD GetInputHostHasDot(bool *aInputHostHasDot); \
  NS_IMETHOD GetOriginalInput(nsACString & aOriginalInput); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIURIFIXUPINFO(_to) \
  NS_IMETHOD GetConsumer(nsISupports * *aConsumer) { return _to GetConsumer(aConsumer); } \
  NS_IMETHOD SetConsumer(nsISupports *aConsumer) { return _to SetConsumer(aConsumer); } \
  NS_IMETHOD GetPreferredURI(nsIURI * *aPreferredURI) { return _to GetPreferredURI(aPreferredURI); } \
  NS_IMETHOD GetFixedURI(nsIURI * *aFixedURI) { return _to GetFixedURI(aFixedURI); } \
  NS_IMETHOD GetFixupUsedKeyword(bool *aFixupUsedKeyword) { return _to GetFixupUsedKeyword(aFixupUsedKeyword); } \
  NS_IMETHOD GetInputHasProtocol(bool *aInputHasProtocol) { return _to GetInputHasProtocol(aInputHasProtocol); } \
  NS_IMETHOD GetInputHostHasDot(bool *aInputHostHasDot) { return _to GetInputHostHasDot(aInputHostHasDot); } \
  NS_IMETHOD GetOriginalInput(nsACString & aOriginalInput) { return _to GetOriginalInput(aOriginalInput); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIURIFIXUPINFO(_to) \
  NS_IMETHOD GetConsumer(nsISupports * *aConsumer) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetConsumer(aConsumer); } \
  NS_IMETHOD SetConsumer(nsISupports *aConsumer) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetConsumer(aConsumer); } \
  NS_IMETHOD GetPreferredURI(nsIURI * *aPreferredURI) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetPreferredURI(aPreferredURI); } \
  NS_IMETHOD GetFixedURI(nsIURI * *aFixedURI) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetFixedURI(aFixedURI); } \
  NS_IMETHOD GetFixupUsedKeyword(bool *aFixupUsedKeyword) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetFixupUsedKeyword(aFixupUsedKeyword); } \
  NS_IMETHOD GetInputHasProtocol(bool *aInputHasProtocol) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetInputHasProtocol(aInputHasProtocol); } \
  NS_IMETHOD GetInputHostHasDot(bool *aInputHostHasDot) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetInputHostHasDot(aInputHostHasDot); } \
  NS_IMETHOD GetOriginalInput(nsACString & aOriginalInput) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetOriginalInput(aOriginalInput); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsURIFixupInfo : public nsIURIFixupInfo
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIURIFIXUPINFO

  nsURIFixupInfo();

private:
  ~nsURIFixupInfo();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS(nsURIFixupInfo, nsIURIFixupInfo)

nsURIFixupInfo::nsURIFixupInfo()
{
  /* member initializers and constructor code */
}

nsURIFixupInfo::~nsURIFixupInfo()
{
  /* destructor code */
}

/* attribute nsISupports consumer; */
NS_IMETHODIMP nsURIFixupInfo::GetConsumer(nsISupports * *aConsumer)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsURIFixupInfo::SetConsumer(nsISupports *aConsumer)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute nsIURI preferredURI; */
NS_IMETHODIMP nsURIFixupInfo::GetPreferredURI(nsIURI * *aPreferredURI)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute nsIURI fixedURI; */
NS_IMETHODIMP nsURIFixupInfo::GetFixedURI(nsIURI * *aFixedURI)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute boolean fixupUsedKeyword; */
NS_IMETHODIMP nsURIFixupInfo::GetFixupUsedKeyword(bool *aFixupUsedKeyword)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute boolean inputHasProtocol; */
NS_IMETHODIMP nsURIFixupInfo::GetInputHasProtocol(bool *aInputHasProtocol)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute boolean inputHostHasDot; */
NS_IMETHODIMP nsURIFixupInfo::GetInputHostHasDot(bool *aInputHostHasDot)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute AUTF8String originalInput; */
NS_IMETHODIMP nsURIFixupInfo::GetOriginalInput(nsACString & aOriginalInput)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


/* starting interface:    nsIURIFixup */
#define NS_IURIFIXUP_IID_STR "80d4932e-bb2e-4afb-98e0-de9cc9ea7d82"

#define NS_IURIFIXUP_IID \
  {0x80d4932e, 0xbb2e, 0x4afb, \
    { 0x98, 0xe0, 0xde, 0x9c, 0xc9, 0xea, 0x7d, 0x82 }}

class NS_NO_VTABLE nsIURIFixup : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IURIFIXUP_IID)

  enum {
    FIXUP_FLAG_NONE = 0U,
    FIXUP_FLAG_ALLOW_KEYWORD_LOOKUP = 1U,
    FIXUP_FLAGS_MAKE_ALTERNATE_URI = 2U,
    FIXUP_FLAG_FIX_SCHEME_TYPOS = 8U
  };

  /* nsIURI createExposableURI (in nsIURI aURI); */
  NS_IMETHOD CreateExposableURI(nsIURI *aURI, nsIURI * *_retval) = 0;

  /* nsIURI createFixupURI (in AUTF8String aURIText, in unsigned long aFixupFlags, [optional] out nsIInputStream aPostData); */
  NS_IMETHOD CreateFixupURI(const nsACString & aURIText, uint32_t aFixupFlags, nsIInputStream * *aPostData, nsIURI * *_retval) = 0;

  /* nsIURIFixupInfo getFixupURIInfo (in AUTF8String aURIText, in unsigned long aFixupFlags, [optional] out nsIInputStream aPostData); */
  NS_IMETHOD GetFixupURIInfo(const nsACString & aURIText, uint32_t aFixupFlags, nsIInputStream * *aPostData, nsIURIFixupInfo * *_retval) = 0;

  /* nsIURI keywordToURI (in AUTF8String aKeyword, [optional] out nsIInputStream aPostData); */
  NS_IMETHOD KeywordToURI(const nsACString & aKeyword, nsIInputStream * *aPostData, nsIURI * *_retval) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIURIFixup, NS_IURIFIXUP_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIURIFIXUP \
  NS_IMETHOD CreateExposableURI(nsIURI *aURI, nsIURI * *_retval); \
  NS_IMETHOD CreateFixupURI(const nsACString & aURIText, uint32_t aFixupFlags, nsIInputStream * *aPostData, nsIURI * *_retval); \
  NS_IMETHOD GetFixupURIInfo(const nsACString & aURIText, uint32_t aFixupFlags, nsIInputStream * *aPostData, nsIURIFixupInfo * *_retval); \
  NS_IMETHOD KeywordToURI(const nsACString & aKeyword, nsIInputStream * *aPostData, nsIURI * *_retval); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIURIFIXUP(_to) \
  NS_IMETHOD CreateExposableURI(nsIURI *aURI, nsIURI * *_retval) { return _to CreateExposableURI(aURI, _retval); } \
  NS_IMETHOD CreateFixupURI(const nsACString & aURIText, uint32_t aFixupFlags, nsIInputStream * *aPostData, nsIURI * *_retval) { return _to CreateFixupURI(aURIText, aFixupFlags, aPostData, _retval); } \
  NS_IMETHOD GetFixupURIInfo(const nsACString & aURIText, uint32_t aFixupFlags, nsIInputStream * *aPostData, nsIURIFixupInfo * *_retval) { return _to GetFixupURIInfo(aURIText, aFixupFlags, aPostData, _retval); } \
  NS_IMETHOD KeywordToURI(const nsACString & aKeyword, nsIInputStream * *aPostData, nsIURI * *_retval) { return _to KeywordToURI(aKeyword, aPostData, _retval); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIURIFIXUP(_to) \
  NS_IMETHOD CreateExposableURI(nsIURI *aURI, nsIURI * *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->CreateExposableURI(aURI, _retval); } \
  NS_IMETHOD CreateFixupURI(const nsACString & aURIText, uint32_t aFixupFlags, nsIInputStream * *aPostData, nsIURI * *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->CreateFixupURI(aURIText, aFixupFlags, aPostData, _retval); } \
  NS_IMETHOD GetFixupURIInfo(const nsACString & aURIText, uint32_t aFixupFlags, nsIInputStream * *aPostData, nsIURIFixupInfo * *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetFixupURIInfo(aURIText, aFixupFlags, aPostData, _retval); } \
  NS_IMETHOD KeywordToURI(const nsACString & aKeyword, nsIInputStream * *aPostData, nsIURI * *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->KeywordToURI(aKeyword, aPostData, _retval); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsURIFixup : public nsIURIFixup
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIURIFIXUP

  nsURIFixup();

private:
  ~nsURIFixup();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS(nsURIFixup, nsIURIFixup)

nsURIFixup::nsURIFixup()
{
  /* member initializers and constructor code */
}

nsURIFixup::~nsURIFixup()
{
  /* destructor code */
}

/* nsIURI createExposableURI (in nsIURI aURI); */
NS_IMETHODIMP nsURIFixup::CreateExposableURI(nsIURI *aURI, nsIURI * *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsIURI createFixupURI (in AUTF8String aURIText, in unsigned long aFixupFlags, [optional] out nsIInputStream aPostData); */
NS_IMETHODIMP nsURIFixup::CreateFixupURI(const nsACString & aURIText, uint32_t aFixupFlags, nsIInputStream * *aPostData, nsIURI * *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsIURIFixupInfo getFixupURIInfo (in AUTF8String aURIText, in unsigned long aFixupFlags, [optional] out nsIInputStream aPostData); */
NS_IMETHODIMP nsURIFixup::GetFixupURIInfo(const nsACString & aURIText, uint32_t aFixupFlags, nsIInputStream * *aPostData, nsIURIFixupInfo * *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsIURI keywordToURI (in AUTF8String aKeyword, [optional] out nsIInputStream aPostData); */
NS_IMETHODIMP nsURIFixup::KeywordToURI(const nsACString & aKeyword, nsIInputStream * *aPostData, nsIURI * *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIURIFixup_h__ */
